A key pair allows you to SSH into your newly created instance. You may select an existing key pair, import a key pair, or generate a new key pair.

A key pair named '{$ctrl.createdKeypair.name$}' was successfully created. This key pair should automatically download.

If not, you can manually dowload this keypair at the following link:

{$ctrl.createdKeypair.name$}

Note: you will not be able to download this later.

| Name | Fingerprint |
--- | --- | --- | ---
Select a key pair from the available key pairs below.
| {$ row.name $} | {$ row.fingerprint $} |

| Name | Fingerprint |
--- | --- | --- | ---
{$ ::trCtrl.helpText.noneAvailText $}
| {$ row.name$} | {$ row.fingerprint $} |